dion 2004/01/07 22:57:23
Modified: src/java/org/apache/maven/jelly/tags/maven Tag:
MAVEN-1_0-BRANCH AddPathTag.java
Log:
Code cleanup:
Remove unused import
Change parameter names to something more descriptive
Revision Changes Path
No revision
No revision
1.13.4.3 +8 -10 maven/src/java/org/apache/maven/jelly/tags/maven/AddPathTag.java
Index: AddPathTag.java
===================================================================
RCS file:
/home/cvs/maven/src/java/org/apache/maven/jelly/tags/maven/AddPathTag.java,v
retrieving revision 1.13.4.2
retrieving revision 1.13.4.3
diff -u -r1.13.4.2 -r1.13.4.3
--- AddPathTag.java 7 Jan 2004 23:14:09 -0000 1.13.4.2
+++ AddPathTag.java 8 Jan 2004 06:57:23 -0000 1.13.4.3
@@ -57,7 +57,6 @@
*/
import org.apache.commons.jelly.JellyTagException;
-import org.apache.commons.jelly.MissingAttributeException;
import org.apache.commons.jelly.XMLOutput;
import org.apache.commons.jelly.tags.ant.AntTagLibrary;
import org.apache.maven.jelly.tags.BaseTagSupport;
@@ -88,7 +87,7 @@
* @throws JellyTagException when anything goes wrong.
*/
public void doTag( XMLOutput output )
- throws MissingAttributeException, JellyTagException
+ throws JellyTagException
{
Project project = AntTagLibrary.getProject( getMavenContext() );
@@ -108,13 +107,12 @@
/**
* Setter for the id property
*
* @param id the reference id of the path in the ant project that will be
* appended to
-
*/
- public void setId( String id )
+ public void setId( String pathId )
{
- this.id = id;
+ id = pathId;
}
/**
@@ -131,12 +129,12 @@
/**
* Setter for the refid property
*
* @param refid the reference id of the path in the ant project that will
will
* be appended
*/
- public void setRefid( String refid )
+ public void setRefid( String pathToAppendId )
{
- this.refid = refid;
+ refid = pathToAppendId;
}
/**
---------------------------------------------------------------------
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]
@@ -108,13 +107,12 @@
* Setter for the id property
*
- * @param id the reference id of the path in the ant project that will be
+ * @param pathId the reference id of the path in the ant project that will be
* appended to
@@ -131,12 +129,12 @@
* Setter for the refid property
*
- * @param refid the reference id of the path in the ant project that will
+ * @param pathToAppendId the reference id of the path in the ant project that
will
* be appended